# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
	imports =
		[ # Include the results of the hardware scan.
			./hardware-configuration.nix
		];

	# Use the systemd-boot EFI boot loader.
	boot.loader.systemd-boot.enable = true;
	boot.loader.efi.canTouchEfiVariables = false;
	boot.plymouth.enable = true;
	
	# Enable automatic updates
	system.autoUpgrade.enable = true;
	system.autoUpgrade.allowReboot = false;

	# Auto cleanup
	nix = {
		package = pkgs.nixUnstable;
    extraOptions = ''
      experimental-features = nix-command flakes
    '';
		autoOptimiseStore = true;
		gc = {
			automatic = true;
			dates = "weekly";
			options = "--delete-older-than 30d";
		};
	};

	networking.hostName = "loft"; # Define your hostname.
	networking.firewall = {
		enable = true;
		allowedTCPPorts = [ 80 8080 8000 443 8888 ];
		allowedTCPPortRanges = [ 
			{ from = 1714; to = 1764; }
		];
		allowedUDPPortRanges = [ 
			{ from = 1714; to = 1764; }
		];
	};
	# networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.

	# Set your time zone.
	time.timeZone = "America/New_York";

	# Configure suspend to disk
	systemd.sleep.extraConfig = ''
	SuspendState=disk
	SuspendMode=suspend
	HibernateMode=platform shutdown
	'';

	nixpkgs.config = {
		allowUnfree = true;
	};

	# The global useDHCP flag is deprecated, therefore explicitly set to false here.
	# Per-interface useDHCP will be mandatory in the future, so this generated config
	# replicates the default behaviour.
	networking.useDHCP = false;
	networking.interfaces.enp0s20u5u4.useDHCP = true;
	networking.interfaces.enp4s0.useDHCP = true;
	networking.interfaces.wlp5s0.useDHCP = true;

	# Configure network proxy if necessary
	# networking.proxy.default = "http://user:password@proxy:port/";
	# networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";
	
	# Enable Avahi Network Discovery
	services.avahi = {
		enable = true;
		nssmdns = true;
		publish.enable = true;
		publish.addresses = true;
	};

	# Select internationalisation properties.
	# i18n.defaultLocale = "en_US.UTF-8";
	# console = {
	#   font = "Lat2-Terminus16";
	#   keyMap = "us";
	# };

	# Enable the GNOME Desktop Environment.
	services.xserver.enable = true;
	services.xserver.displayManager.gdm.enable = true;
	services.xserver.desktopManager.gnome.enable = true;
	services.gnome.chrome-gnome-shell.enable = true;
	programs.dconf.enable = true;

	# Font Settings
	fonts = {
		fonts = with pkgs; [
						roboto
						inter
		];
		fontconfig = {
			localConf = ''
				<alias>
					<family>system-ui</family>
					<prefer>
						<family>Inter</family>
						<family>Roboto</family>
						<family>Cantarell</family>
						<family>Liberation Sans</family>
						<family>DejaVu Sans</family>
					</prefer>
				</alias>
			'';
			};
	};
	
	# Configure keymap in X11
	# services.xserver.layout = "us";
	# services.xserver.xkbOptions = "eurosign:e";

	# Enable CUPS to print documents.
	services.printing = {
				enable = true;
				drivers = [ pkgs.epson-escpr2 ];
	};

	# Enable sound.
	sound.enable = true;
	hardware.pulseaudio.enable = true;

	# Enable touchpad support (enabled default in most desktopManager).
	# services.xserver.libinput.enable = true;

	# Enable Docker
	virtualisation.docker.enable = true;

	programs.zsh.enable = true;

	# users.defaultUserShell = pkgs.zsh;
	# Define a user account. Don't forget to set a password with ‘passwd’.
	users.users.michael = {
		 isNormalUser = true;
		 description = "Michael Thomas";
		 extraGroups = [ "wheel" "docker" "networkmanager" ]; # Enable ‘sudo’ for the user.
		 shell = pkgs.zsh;
	 };

	# List packages installed in system profile. To search, run:
	# $ nix search wget
	environment.systemPackages = with pkgs; [
		wget micro
		google-chrome
		pkgs.gnome3.gnome-tweaks
		gnomeExtensions.gsconnect
	];

	# Some programs need SUID wrappers, can be configured further or are
	# started in user sessions.
	# programs.mtr.enable = true;
	# programs.gnupg.agent = {
	#   enable = true;
	#   enableSSHSupport = true;
	# };

	# List services that you want to enable:

	# Enable Flatpak support
	services.flatpak.enable = true;
	services.fwupd.enable = true;
	appstream.enable = true;

	# Enable the OpenSSH daemon.
	# services.openssh.enable = true;

	# Open ports in the firewall.
	# networking.firewall.allowedTCPPorts = [ ... ];
	# networking.firewall.allowedUDPPorts = [ ... ];
	# Or disable the firewall altogether.
	# networking.firewall.enable = false;

	# This value determines the NixOS release from which the default
	# settings for stateful data, like file locations and database versions
	# on your system were taken. It‘s perfectly fine and recommended to leave
	# this value at the release version of the first install of this system.
	# Before changing this value read the documentation for this option
	# (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
	system.stateVersion = "20.09"; # Did you read the comment?

}